#
# spec file for package python-kde4
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-kde4
Version:        4.14.3
Release:        6.11
Summary:        Python bindings for KDE 4
License:        LGPL-2.1+ and GPL-2.0+
Group:          Development/Libraries/KDE
Url:            https://projects.kde.org/projects/kde/kdebindings/pykde4
Source0:        pykde4-%{version}.tar.xz
Patch0:         arm-qreal-float.patch
Patch1:         arm-avoid-return-type-confusion.patch
# PATCH-FIX-UPSTREAM fix-build.diff boo#975915 wbauer@tmo.at -- fix build on Factory
Patch2:         fix-build.diff
# PATCH-FIX-UPSTREAM fix-build-with-sip-4.19.patch -- fix build with python-sip 4.19
Patch3:         fix-build-with-sip-4.19.patch
# PATCH-FIX-OPENSUSE Annotate-KAutoMount-as-Abstract.patch boo#1026767 wbauer@tmo.at -- fix build with python-sip 4.19.1
Patch4:         Annotate-KAutoMount-as-Abstract.patch
BuildRequires:  fdupes
BuildRequires:  libjasper-devel
BuildRequires:  libkde4-devel
BuildRequires:  python-qt4-devel
BuildRequires:  xz
Requires:       python-qt4
Requires:       update-alternatives
Recommends:     %{name}-doc
Recommends:     %{name}-khtml
Recommends:     %{name}-knewstuff
Recommends:     %{name}-plasma
Recommends:     %{name}-phonon
# no more nepomuk & soprano with KDE's 4.13 release
Obsoletes:      %{name}-akonadi
Obsoletes:      %{name}-nepomuk
Obsoletes:      %{name}-soprano
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitearch: %global python_sitearch %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib(1)")}
%endif
%requires_python_sip_api
%kde4_runtime_requires

%description
Bindings for the KDE Development Platform based on PyQt4 and SIP. Use of these bindings
allows to write Python applications that use the KDE C++ libraries.

%package doc
Summary:        Documentation for Python bindings for KDE 4
Group:          Development/Libraries/KDE
Requires:       %{name} = %{version}

%description doc
This package contains documentation for the KDE 4 python bindings.

%package khtml
Summary:        Python bindings for KDE 4 - KHTML
Group:          Development/Libraries/KDE
Requires:       %{name} = %{version}
%kde4_runtime_requires

%description khtml
This package contains Python bindings for the KHTML rendering engine, which can be
used from Python applications.

%package knewstuff
Summary:        Python bindings for KDE 4 - KNewStuff
Group:          Development/Libraries/KDE
Requires:       %{name} = %{version}

%description knewstuff
This package contains Python bindings for the KNewStuff library. It allows the use of
the GHNS framework from Python.

%package plasma
Summary:        Python bindings for KDE 4 - Plasma
Group:          Development/Libraries/KDE
Requires:       %{name} = %{version}
%kde4_runtime_requires

%description plasma
This package contains Python bindings for the Plasma library. In 
conjunction with the Python script engne, it allows writing Plasma widgets
in Python.

%package phonon
Summary:        Python bindings for KDE 4 - Phonon
Group:          Development/Libraries/KDE
Requires:       %{name} = %{version}

%description phonon
This package contains Python bindings for the Phonon multimedia libraries. 
These bindings allow the use of Phonon, and its associated media capabilities,
in Python applications.

%package devel
Summary:        Development files of %{name}
Group:          Development/Libraries/KDE
Requires:       %{name} = %{version}
Provides:       %{name}-common = %{version}
#TODO: Change back to '<' after next version update:
Obsoletes:      %{name}-common <= %{version}
Requires:       %{name}-khtml = %{version}
Requires:       %{name}-knewstuff = %{version}
Requires:       %{name}-phonon = %{version}
Requires:       %{name}-plasma = %{version}
Requires:       python-qt4-devel

%description devel
This package contains development files for the Python bindings for the
KDE Development Platform.  It also contains common files required to build
additional bindings for PyKDE4. It is used with either Python 2 or 3.

%prep
%setup -q -n pykde4-%{version}
%patch0
%ifarch %arm
%patch1
%endif
%patch2 -p1
%patch3 -p1
%patch4 -p1

%build
%cmake_kde4 -d build -- -DPYKDEUIC4_ALTINSTALL=TRUE -DINSTALL_PYTHON_FILES_IN_PYTHON_PREFIX=TRUE
%make_jobs

%install
cd build
%kde4_makeinstall
%fdupes -s %{buildroot}%{_datadir}
rm -rf %{buildroot}%{_kde4_appsdir}/pykde4/examples

%post
update-alternatives --install %{_bindir}/pykdeuic4 pykdeuic4 %{_bindir}/pykdeuic4-%{py_ver} 50

%postun
update-alternatives --remove pykdeuic4 %{_bindir}/pykdeuic4-%{py_ver}
if [ -e "%{_sysconfdir}/alternatives/pykdeuic4" ]; then
    update-alternatives --auto pykdeuic4
fi

%files
%defattr(-,root,root)
%doc COPYING COPYING.LESSER
%{_kde4_appsdir}/pykde4
%{_bindir}/pykdeuic4-%{py_ver}
%{_kde4_modulesdir}/kpythonpluginfactory.so
%dir %{python_sitearch}/PyKDE4
%{python_sitearch}/PyKDE4/__init__.*
%{python_sitearch}/PyKDE4/dnssd.so
%{python_sitearch}/PyKDE4/kdecore.so
%{python_sitearch}/PyKDE4/kdeui.so
%{python_sitearch}/PyKDE4/kio.so
%{python_sitearch}/PyKDE4/kparts.so
%{python_sitearch}/PyKDE4/kterminal.so
%{python_sitearch}/PyKDE4/ktexteditor.so
%{python_sitearch}/PyKDE4/kutils.so
%{python_sitearch}/PyKDE4/solid.so
%if 0%{?suse_version} < 1330
%{python_sitearch}/PyKDE4/pykdeconfig.*
%endif
%{python_sitearch}/PyQt4/uic/widget-plugins
%{python_sitearch}/PyQt4/uic/pykdeuic4.*

%files doc
%doc docs/html

%files khtml
%defattr(-,root,root)
%{python_sitearch}/PyKDE4/khtml.so

%files knewstuff
%defattr(-,root,root)
%{python_sitearch}/PyKDE4/knewstuff.so

%files plasma
%defattr(-,root,root)
%{python_sitearch}/PyKDE4/plasma.so

%files phonon
%defattr(-,root,root)
%{python_sitearch}/PyKDE4/phonon.so

%files devel
%defattr(-,root,root)
%doc examples
%{_datadir}/sip/PyKDE4

%changelog
* Mon May  1 2017 wbauer@tmo.at
- Remove pykdeconfig.py from the file list in Tumbleweed to fix
  build after the latest changes to python-qt4
* Sat Feb 25 2017 wbauer@tmo.at
- Add Annotate-KAutoMount-as-Abstract.patch to fix build with
  python-sip 4.19.1 (boo#1026767)
* Fri Jan 13 2017 wbauer@tmo.at
- Remove unused okular-devel build requirement
- Add fix-build-with-sip-4.19.patch to fix build with python-sip
  4.19
* Mon Apr 18 2016 wbauer@tmo.at
- Add fix-build.diff to fix the build in Factory (boo#975915)
* Wed Jan 27 2016 tittiatcoke@gmail.com
- Drop BuildRequires on kdepimlibs4 due to the change to the
  Frameworks version of akonadi.
* Sun May 17 2015 opensuse@cboltz.de
- split off -doc package with 26 MB of HTML documentation
* Sun Apr  5 2015 dmueller@suse.com
- add arm-qreal-float.patch, arm-avoid-return-type-confusion.patch
  to fix build on ARM
* Sun Nov  9 2014 tittiatcoke@gmail.com
- Update to 4.14.3
  * KDE 4.14.3 SC Bugfix Release
  * See http://www.kde.org/announcements/announce-4.14.3.php
* Sun Oct 12 2014 tittiatcoke@gmail.com
- Update to 4.14.2
  * KDE 4.14.2 SC Bugfix Release
  * See http://www.kde.org/announcements/announce-4.14.2.php
* Sat Sep 13 2014 tittiatcoke@gmail.com
- Update to 4.14.1
  * KDE 4.14.1 SC Bugfix Release
  * See http://www.kde.org/announcements/announce-4.14.1.php
* Fri Aug 15 2014 tittiatcoke@gmail.com
- Update to 4.14.0
  * KDE 4.14.0 SC Final Release
  * See http://www.kde.org/announcements/4.14/
- Drop patch python-sip-4.15.5.fixes.diff due to upstream
  inclusion
* Thu Jul 17 2014 cgiboudeaux@gmx.com
- Update to 4.13.90
  * KDE 4.14 Beta 2 release
  * See http://www.kde.org/announcements/announce-4.14-beta2.php
* Thu Jul 10 2014 cgiboudeaux@gmx.com
- Update to 4.13.80
  * KDE 4.14 Beta 1 release
  * See http://www.kde.org/announcements/announce-4.14-beta1.php
* Fri Jun 20 2014 tittiatcoke@gmail.com
- Updated patch python-sip-4.15.5.fixes.diff to include additional
  fixes for python-sip version 4.16.
* Sun Jun  8 2014 tittiatcoke@gmail.com
- Update to 4.13.2
  * KDE 4.13  release
  * See http://www.kde.org/announcements/announce-4.13.2.php
* Fri May  9 2014 tittiatcoke@gmail.com
- Update to 4.13.1
  * KDE 4.13.1  bug fix release
  * See http://www.kde.org/announcements/announce-4.13.1.php
* Sat Apr 19 2014 hrvoje.senjan@gmail.com
- Obsolete nepomuk & soprano bindings, which are no longer built
  with KDE's 4.13 release
* Fri Apr 11 2014 tittiatcoke@gmail.com
- Update to 4.13.0
  * KDE 4.13  release
  * See http://www.kde.org/announcements/4.13/
* Thu Mar 27 2014 tittiatcoke@gmail.com
- Update to 4.12.97
  * KDE 4.13 RC  release
  * See http://www.kde.org/announcements/announce-4.13-rc.php
* Mon Mar 24 2014 tittiatcoke@gmail.com
- Add patch python-sip-4.15.5.fixes.diff to resolve build issues
  with a newer python-sip
* Thu Mar 20 2014 tittiatcoke@gmail.com
- Update to 4.12.95
  * KDE 4.13 Beta 3  release
  * See http://www.kde.org/announcements/announce-4.13-beta3.php
* Thu Mar 13 2014 tittiatcoke@gmail.com
- Update to 4.12.90
  * KDE 4.13 Beta 2  release
  * See http://www.kde.org/announcements/announce-4.13-beta2.php
* Fri Mar  7 2014 tittiatcoke@gmail.com
- Update to 4.12.80
  * KDE 4.13 Beta 1  release
  * See http://www.kde.org/announcements/announce-4.13-beta1.php
* Sat Feb  1 2014 tittiatcoke@gmail.com
- Update to 4.12.2
  * KDE 4.12.2  release
  * See http://www.kde.org/announcements/announce-4.12.2.php
* Sat Jan 11 2014 tittiatcoke@gmail.com
- Update to 4.12.1
  * KDE 4.12.1  release
  * See http://www.kde.org/announcements/announce-4.12.1.php
* Sat Dec 14 2013 tittiatcoke@gmail.com
- Update to 4.12.0
  * KDE 4.12.0  release
  * See http://www.kde.org/announcements/4.12.php
* Fri Nov 29 2013 tittiatcoke@gmail.com
- Update to 4.11.97
  * KDE 4.12 RC 1 release
  * See http://www.kde.org/announcements/announce-4.12-rc.php
* Sat Nov 23 2013 tittiatcoke@gmail.com
- Update to 4.11.95
  * KDE 4.12 Beta 3 release
  * See http://www.kde.org/announcements/announce-4.12-beta3.php
* Sat Nov 16 2013 tittiatcoke@gmail.com
- Update to 4.11.90
  * KDE 4.12 Beta 2 release
  * See http://www.kde.org/announcements/announce-4.12-beta2.php
* Sat Nov  9 2013 tittiatcoke@gmail.com
- Update to 4.11.80
  * KDE 4.12 Beta 1 release
  * See http://www.kde.org/announcements/announce-4.12-beta1.php
* Sat Nov  2 2013 tittiatcoke@gmail.com
- Update to 4.11.3
  * KDE 4.11.3 bugfix release
  * See http://www.kde.org/announcements/announce-4.11.3.php
* Sat Sep 28 2013 tittiatcoke@gmail.com
- Update to 4.11.2
  * KDE 4.11.2 bugfix release
  * See http://www.kde.org/announcements/announce-4.11.2.php
- Dropped patches due to upstream inclusion:
  pykde4-build-with-sip-415.diff
  pykde4-cmake-options.diff
* Fri Sep 13 2013 hrvoje.senjan@gmail.com
- Make python(3)-kde4-devel require all subpackages
* Tue Sep 10 2013 lbeltrame@kde.org
- Add pykde4-build-with-sip-415.diff and pykde4-cmake-options.diff:
  fix compilation with SIP 4.15 (bugs.kde.org 323899)
* Sun Sep  1 2013 tittiatcoke@gmail.com
- Update to 4.11.1
  * KDE 4.11.1 bugfix release
  * See http://www.kde.org/announcements/announce-4.11.1.php
* Thu Aug  8 2013 tittiatcoke@gmail.com
- Update to 4.11.0
  * KDE 4.11 Final release
  * See http://www.kde.org/announcements/4.11/
* Thu Jul 25 2013 hrvoje.senjan@gmail.com
- Update to 4.10.97
  * KDE 4.11 RC 2 release
  * See http://www.kde.org/announcements/announce-4.11-rc2.php
* Wed Jul 24 2013 hrvoje.senjan@gmail.com
- BuildRequire only libkde4-devel, instead of kdebase4-workspace-devel
* Mon Jul 15 2013 cgiboudeaux@gmx.com
- Update to 4.10.95
  * KDE 4.11 RC 1 release
  * See http://www.kde.org/announcements/announce-4.11-rc1.php
* Tue Jul  9 2013 lbeltrame@kde.org
- Add %%requires_python_sip_api to ensure that the correct SIP API
  is used all the time, preventing runtime issues
* Thu Jun 27 2013 tittiatcoke@gmail.com
- Update to 4.10.90
  * KDE 4.11 Beta 1 release
  * See http://www.kde.org/announcements/announce-4.11-beta2.php
* Thu Jun 13 2013 tittiatcoke@gmail.com
- Update to 4.10.80
  * KDE 4.11 Beta 1 release
  * See http://www.kde.org/announcements/announce-4.11-beta1.php
* Sat Jun  1 2013 tittiatcoke@gmail.com
- Update to 4.10.4
  * Bugfix release
  * See http://www.kde.org/announcements/announce-4.10.4.php
  * resolves bnc#8122760
* Sat May  4 2013 tittiatcoke@gmail.com
- Update to 4.10.3
  * Bugfix release
  * See http://www.kde.org/announcements/announce-4.10.3.php
  * resolves bnc#818500
* Mon Apr 22 2013 hrvoje.senjan@gmail.com
- Recommend all subpackages for the main package, so users don't
  have go guess which module is required (bnc#816432, bnc#816562)
* Sun Apr 14 2013 lbeltrame@kde.org
- Update descriptions so that the purpose of each package is clearer
* Mon Mar 25 2013 speilicke@suse.com
- Split out sub-packages for seldomly-used modules that also have heavy
  requirements: akonadi, khtml, knewstuff, phonon, plasma, nepomuk, soprano
- Merge common package into devel package. This previously made little
  sense and the devel package was empty
- Proper update-alternatives for Python3
- ldconfig shouldn't be needed
- %%py_requires isn't really needed (especially not for Py3 / oS)
* Sat Mar  2 2013 tittiatcoke@gmail.com
- Update to 4.10.1
  * Contains bug fixes. See http://www.kde.org/announcements/
  for more information
* Tue Feb  5 2013 ctrippe@opensuse.org
- Require python-qt4 as this is needed at runtime (bnc#799925)
* Thu Jan 31 2013 tittiatcoke@gmail.com
- Update to 4.10.0
  * This is the final release for 4.10. Contains bugfixes
* Fri Jan 18 2013 lbeltrame@kde.org
- Add alternatives support for co-installability
- Build with -DPYKDEUIC4_ALTINSTALL=TRUE to let %%post generate the
  command
- Use %%{py_ver} instead of hardcoding a version
* Thu Jan 17 2013 tittiatcoke@gmail.com
- Update to 4.9.98
  * This is the third RC release for 4.10. Contains bugfixes
- Drop fix-symlink-for-pykdeuic4.patch, included upstream
* Thu Jan  3 2013 tittiatcoke@gmail.com
- Update to 4.9.97
  * This is the second RC release for 4.10. Contains bugfixes
- Added patch to ensure installation of /usr/bin/pykdeuic4
  (fix-symlink-for-pykdeuic4.patch)
* Wed Dec 19 2012 tittiatcoke@gmail.com
- Update to 4.9.95
  * This is the first RC release for 4.10. Contains bugfixes
* Thu Dec  6 2012 cfarrell@suse.com
- license update: LGPL-2.1+ and GPL-2.0+
  Contains components licensed under GPL-2.0+
* Sun Dec  2 2012 tittiatcoke@gmail.com
- Update to 4.9.90
  * See http://www.kde.org/announcements/announce-4.10-beta2.php
- Removed patch pykde4-fix-strings.diff due to upstream inclusion
* Sat Nov 24 2012 lbeltrame@kde.org
- Add patch pykde4-fix-strings.diff to fix string handling in
  PyKDE4 (fixed upstream after Beta 1)
* Sat Nov 24 2012 tittiatcoke@gmail.com
- Update to 4.9.80
  * See http://www.kde.org/announcements/announce-4.10-beta1.php
* Sat Nov 17 2012 lbeltrame@kde.org
- Add a -common package for installation in parallel of SIP files
- Adjust description
* Fri Nov  2 2012 tittiatcoke@gmail.com
- Update to 4.9.3
  * see http://kde.org/announcements/announce-4.9.3.php for details
- Removed patch fix-for-python.diff, as that the fix is now
  upstream
* Sat Sep 29 2012 tittiatcoke@gmail.com
- Update to 4.9.2
  * see http://kde.org/announcements/announce-4.9.2.php for details
* Wed Sep  5 2012 dmueller@suse.com
- update to 4.9.1
  * see http://kde.org/announcements/4.9.1/ for details
* Mon Jul 30 2012 dmueller@suse.com
- update to 4.8.5
  * see http://kde.org/announcements/changelogs/changelog4_8_4to4_8_5.php for details
* Fri Jun  1 2012 dmueller@suse.com
- update to 4.8.4
  * see http://kde.org/announcements/changelogs/changelog4_8_3to4_8_4.php for details
* Sun Apr 29 2012 dmueller@suse.com
- update to 4.8.3
  * see http://kde.org/announcements/changelogs/changelog4_8_2to4_8_3.php for details
* Sat Mar 31 2012 wstephenson@suse.com
- Add xz to BuildRequires
* Thu Mar 29 2012 dmueller@suse.de
- update to 4.8.2
  * see http://kde.org/announcements/changelogs/changelog4_8_1to4_8_2.php for details
* Fri Mar  2 2012 dmueller@suse.de
- update to 4.8.1
  * see http://kde.org/announcements/changelogs/changelog4_8_0to4_8_1.php for details
* Wed Jan 18 2012 dmueller@suse.de
- update to 4.8.0
  * first stable release of KDE 4.8 (only critical fixes over 4.7.98)
  * see http://kde.org/announcements/4.8/ for details
* Wed Dec  7 2011 coolo@suse.com
- fix license to be in spdx.org format
* Fri Dec  2 2011 dmueller@suse.de
- update to 4.7.4
  * see http://kde.org/announcements/changelogs/changelog4_7_3to4_7_4.php for details
* Wed Nov  2 2011 dmueller@suse.de
- update to 4.7.3
  * see http://kde.org/announcements/changelogs/changelog4_7_2to4_7_3.php for details
* Sun Oct  2 2011 dmueller@suse.de
- update to 4.7.2
  * see http://kde.org/announcements/changelogs/changelog4_7_1to4_7_2.php for details
* Thu Sep  1 2011 dmueller@suse.de
- update to 4.7.1
  * Bugfixes over KDE 4.7.0
  * see http://kde.org/announcements/changelogs/changelog4_7_0to4_7_1.php for details
* Fri Aug 26 2011 toddrme2178@gmail.com
- Changed URL to point to the page for the project
- Changed summary (the bindings are not only for KDE libraries)
- Fixed typo in -devel summary
- Changed description to upstream version
- Removed redundant buildrequires
- Cleaned up spec file formatting
* Fri Aug 26 2011 mlin@novell.com
- fixes for RPMLINT warnings
  * add %%kde4_runtime_requires macro
  * add %%kde4_akonadi_requires macro
  * modified Summary for begin with a capital letter
  * add Url tag
  * add fdupes for duplicated files
  * modified description for contents longer than the summary
  * add %%py_requires to avoid dependencies warning
- clean up the specfile formatting
* Fri Jul 22 2011 dmueller@suse.de
- update to 4.7.0
  * Small fixes over KDE 4.7 RC2
  * see http://kde.org/announcements/4.7 for details
* Thu Jul 21 2011 idonmez@novell.com
- Update to 4.6.95
* Fri Jul  1 2011 dmueller@suse.de
- update to 4.6.5
  * Bugfixes over KDE 4.6.5
  * see http://kde.org/announcements/changelogs/changelog4_6_4to4_6_5.php for details
* Fri Jun  3 2011 dmueller@suse.de
- update to 4.6.4
  * Bugfixes over KDE 4.6.3
  * see http://kde.org/announcements/changelogs/changelog4_6_3to4_6_4.php for details
* Thu Apr 28 2011 dmueller@suse.de
- update to 4.6.3
  * Bugfixes over KDE 4.6.2
  * see http://kde.org/announcements/changelogs/changelog4_6_2to4_6_3.php for details
* Sat Apr 16 2011 einar@heavensinferno.net
- Add pykde4_fix_phonon.patch: Fixes the use of Phonon.VideoWidget
  and Phonon.AudioOutput in Python. Fix for bugs.kde.org 188315,
  taken from KDE SVN rev 1228245
* Sun Apr  3 2011 idoenmez@novell.com
- Add phonon_smoke_deprecated.patch: fix phonon compilation,
  patch taken from KDE SVN revision 1208598
* Fri Apr  1 2011 dmueller@suse.de
- update to 4.6.2
  * Bugfixes over KDE 4.6.1
  * see http://kde.org/announcements/changelogs/changelog4_6_1to4_6_2.php for details
* Tue Mar  8 2011 dmueller@suse.de
- update to 4.6.1
  * Bugfixes over KDE 4.6.0
  * see http://kde.org/announcements/changelogs/changelog4_6_0to4_6_1.php for details
* Wed Jan 19 2011 dmueller@suse.de
- update to 4.6.0
  * For highlights, see http://kde.org/announcements/4.6
* Mon Jan 10 2011 coolo@novell.com
- ran spec-cleaner and made kde dependency version specific
* Tue Jan  4 2011 dmueller@suse.de
- update to 4.5.95
  * KDE 4.6 RC2
  * no upstream changelog available.
* Thu Dec 30 2010 einar@heavensinferno.net
- Added Patch1
  * Make pykdeuic4 work with recent python-qt4 and python-sip
    (upstreamed in trunk)
* Wed Dec 22 2010 dmueller@suse.de
- update to 4.5.90
  * KDE 4.6 RC1
  * no upstream changelog available.
* Fri Dec  3 2010 dmueller@suse.de
- update to 4.5.85
  * KDE 4.6 Beta2
  * Final Beta before RC, various fixes from Beta1
  * no upstream changelog available.
* Fri Nov 19 2010 dmueller@suse.de
- update to 4.5.80
  * KDE 4.6 Beta1
  * no upstream changelog available.
* Thu Oct 28 2010 dmueller@suse.de
- update to 4.5.3
  * see http://kde.org/announcements/changelogs/changelog4_5_2to4_5_3.php for details
* Mon Oct 18 2010 coolo@novell.com
- fix perl requires for perl-kde4
* Sat Oct  9 2010 speilicke@novell.com
- fix ruby-qt4-devel requirement on ruby-qt4
* Fri Oct  8 2010 coolo@novell.com
- add patch from fedora to fix crash in smokegen
* Thu Sep 30 2010 dmueller@suse.de
- update to 4.5.2
  * see http://kde.org/announcements/changelogs/changelog4_5_1to4_5_2.php for details
* Tue Sep 14 2010 llunak@novell.com
- split ruby Qt4 bindings to ruby-qt4 and ruby-qt4-devel, again
  (bnc #551653)
* Thu Sep  2 2010 dmueller@suse.de
- fix build against newer python-qt4
* Fri Aug 27 2010 dmueller@suse.de
- update to 4.5.1
  * see http://kde.org/announcements/changelogs/changelog4_5_0to4_5_1.php for details
* Thu Jul 29 2010 dmueller@suse.de
- update to 4.5.0
  * KDE 4.5.0 final (version bump over RC3)
* Fri Jul 23 2010 dmueller@suse.de
- update to 4.4.95
  * KDE 4.5 RC3 (not announced)
  * critical fixes for 4.5.0 release
* Fri Jul 16 2010 dmueller@suse.de
- update to 4.4.93svn1149349
* Wed Jul  7 2010 dmueller@suse.de
- update to 4.4.5
  * bugfixes over 4.4.4
  * see http://kde.org/announcements/changelogs/changelog4_4_4to4_4_5.php for details
* Fri Jun 18 2010 dmueller@suse.de
- update to 4.4.4
  * bugfixes over 4.4.3
  * see http://kde.org/announcements/changelogs/changelog4_4_3to4_4_ 4.php for details
  * for most modules only version number as a change (4_4_BRANCH.diff already contained the diff
* Mon May 17 2010 llunak@novell.com
- update 4_4_BRANCH.diff: various fixes, translation updates
* Thu Apr 29 2010 dmueller@suse.de
- update to 4.4.3
  * bugfixes over 4.4.2
  * see http://kde.org/announcements/changelogs/changelog4_4_2to4_4_3.php for details
* Fri Mar 26 2010 dmueller@suse.de
- update to 4.4.2
  * bugfixes over 4.4.1
  * see http://kde.org/announcements/changelogs/changelog4_4_1to4_4_2.php for details
* Fri Feb 26 2010 dmueller@suse.de
- update to 4.4.1
  * bugfixes over 4.4.0
  * see http://kde.org/announcements/changelogs/changelog4_4_0to4_4_1.php for details
* Thu Feb  4 2010 dmueller@suse.de
- update to 4.4.0
  * Critical bugfixes only over 4.3.98
  * see http://www.kde.org/announcements/4.4/ for general overview
* Sun Jan 31 2010 dmueller@suse.de
- update to 4.3.98
  * see http://www.kde.org/announcements/announce-4.4-rc3.php for details
* Wed Jan 20 2010 dmueller@suse.de
- update to 4.3.95
  * see http://www.kde.org/announcements/announce-4.4-rc2.php for details
* Wed Jan  6 2010 dmueller@suse.de
- update to 4.3.90
  * see http://www.kde.org/announcements/announce-4.4-rc1.php for details
* Fri Dec 18 2009 dmueller@suse.de
- update to 4.3.85
  * see http://www.kde.org/announcements/announce-4.4-beta2.php for details
* Sat Dec  5 2009 llunak@novell.com
- remove kate-devel buildrequires for python-kde4 in order
  to build sooner e.g. kdeutils which has python, the depedency
  does not seem to be needed anyway
* Fri Dec  4 2009 dmueller@suse.de
- update to 4.3.80:
  * see http://techbase.kde.org/Schedules/KDE4/4.4_Feature_Plan
* Mon Nov  2 2009 dmueller@suse.de
- update to 4.3.3
  * see http://kde.org/announcements/changelogs/changelog4_3_2to4_3_3.php for details
* Mon Nov  2 2009 dmacvicar@suse.de
- split ruby Qt4 bindings to ruby-qt4 and ruby-qt4-devel
  (bnc #551653)
* Thu Sep 24 2009 beineri@opensuse.org
- update 4_3_BRANCH.diff
* Fri Aug 28 2009 dmueller@suse.de
- update to 4.3.1
  * see http://kde.org/announcements/changelogs/changelog4_3_0to4_3_1.php for details
* Wed Jul 29 2009 dmueller@suse.de
- update to 4.3.0
  * see http://kde.org/announcements/4.3 for details
* Tue Jul 21 2009 dmueller@suse.de
- update to 4.2.98
* Sat Jul 11 2009 beineri@opensuse.org
- create a python-kde4-devel sub-package
* Thu Jul  9 2009 dmueller@suse.de
- update to 4.2.96
* Wed Jun 24 2009 dmueller@suse.de
- update to 4.2.95
* Sat Jun 20 2009 beineri@opensuse.org
- update build requires
* Wed Jun  3 2009 dmueller@suse.de
- update to 4.2.90
* Wed May 27 2009 dmueller@suse.de
- update to 4.2.88svn973768
* Thu May 21 2009 beineri@opensuse.org
- fix build with gcc-4.4
* Sun May 17 2009 beineri@opensuse.org
- update to 4.2.85 (KDE 4.3 Beta1)
* Thu Apr 30 2009 dmueller@suse.de
- update to 4.2.3
  * see http://kde.org/announcements/changelogs/changelog4_2_2to4_2_3.php
* Thu Mar 26 2009 dmueller@suse.de
- update to 4.2.2
  * see http://kde.org/announcements/changelogs/changelog4_2_1to4_2_2.php
* Fri Mar 13 2009 wstephenson@suse.de
- Add packageconfig files from trunk needed for Mono development
  Patch by Eric Butler
* Fri Feb 27 2009 dmueller@suse.de
- update to 4.2.1
  * see http://kde.org/announcements/changelogs/changelog4_2_0to4_2_1.php
* Wed Feb 18 2009 wstephenson@suse.de
- Build Mono bindings
* Thu Jan 22 2009 dmueller@suse.de
- update to 4.2.0
* Tue Jan 13 2009 dmueller@suse.de
- update to 4.1.96
* Sat Jan 10 2009 dmueller@suse.de
- update to KDE 4.1.87 (KDE 4.2 Januar snapshot)
* Mon Dec  8 2008 dmueller@suse.de
- fix build against sip 4.7.9
* Fri Oct 31 2008 dmueller@suse.de
- update to 4.1.3
  * see http://kde.org/announcements/changelogs/changelog4_1_2to4_1_3.php
* Mon Oct 13 2008 stbinner@suse.de
- fix build of ruby-kde4
* Wed Oct  8 2008 dmueller@suse.de
- add missing post/un
* Sun Sep 28 2008 stbinner@suse.de
- update to 4.1.2
* Wed Sep 10 2008 ro@suse.de
- use py_sitedir macro
* Thu Aug 28 2008 dmueller@suse.de
- update to 4.1.1
* Mon Aug 18 2008 stbinner@suse.de
- fix build of ruby-kde4
* Thu Aug  7 2008 dmueller@suse.de
- fix debug package requires
* Fri Aug  1 2008 ro@suse.de
- fix requires for debuginfo package
* Tue Jul 29 2008 dmueller@suse.de
- add missing python requires
* Wed Jul 23 2008 dmueller@suse.de
- update to 4.1.0
* Tue Jul 22 2008 dmueller@suse.de
- update to 4.0.99:
  * add fix for python-kde4 on x86_64
* Mon Jul  7 2008 dmueller@suse.de
- update to 4.0.85
* Wed Jun 18 2008 dmueller@suse.de
- update to 4.0.83
* Tue Jun 10 2008 dmueller@suse.de
- update to 4.0.82
* Mon Jun  9 2008 dmueller@suse.de
- update to 4.0.81
* Wed May 28 2008 dmueller@suse.de
- fix fallout from stricter checks in SIP 4.7.6
* Wed May  7 2008 dmueller@suse.de
- fix buildrequires
* Thu May  1 2008 dmueller@suse.de
- update to 4.0.4
  * http://www.kde.org/announcements/changelogs/changelog4_0_3to4_0_4.php
* Thu Apr 24 2008 dmueller@suse.de
- fix filelist
* Mon Apr 21 2008 dmueller@suse.de
- add missing ldconfig calls to post/un
* Thu Mar 27 2008 dmueller@suse.de
- update to 4.0.3
* Wed Feb 27 2008 dmueller@suse.de
- update to 4.0.2
* Thu Jan 31 2008 dmueller@suse.de
- update to 4.0.1
* Sun Jan  6 2008 stbinner@suse.de
- update to 4.0 release
* Wed Jan  2 2008 stbinner@suse.de
- update to 3.97.2
* Sun Dec 16 2007 dmueller@suse.de
- update to 3.97.1
* Wed Dec  5 2007 dmueller@suse.de
- update to 3.97.0
* Tue Dec  4 2007 dmueller@suse.de
- update to 3.96.3
* Sat Dec  1 2007 dmueller@suse.de
- update to 3.96.2
* Wed Nov 21 2007 dmueller@suse.de
- update to 3.96.1
* Wed Nov 14 2007 dmueller@suse.de
- update to 3.96.0
* Wed Nov  7 2007 dmueller@suse.de
- update to 3.95.2
* Thu Nov  1 2007 dmueller@suse.de
- update to 3.95.1
* Fri Oct 26 2007 dmueller@suse.de
- update to KDE 4.0 beta4
* Thu Oct 18 2007 dmueller@suse.de
- KDE 3.94.1 update
* Thu Oct 11 2007 dmueller@suse.de
- update to KDE 4.0 Beta3
